*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus

***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			         				1
#DEFINE cnOUTPUT_PRINT			         				2
#DEFINE cnOUTPUT_EMAIL			         				3
#DEFINE cnOUTPUT_FILE		 	         				4

***************************************************************************************************************************
*-- IMAGE's output file formats
***************************************************************************************************************************
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_BMP          		1
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_JPG					2
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_GIF					3
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_TIF					4
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_PNG					5

***************************************************************************************************************************
*-- Enumeration type for the various symbol shapes that are available
***************************************************************************************************************************
#DEFINE cnCHART_SYMBOL_TYPE_SQUARE						0
#DEFINE cnCHART_SYMBOL_TYPE_DIAMOND						1
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE					2
#DEFINE cnCHART_SYMBOL_TYPE_CIRCLE						3
#DEFINE cnCHART_SYMBOL_TYPE_XCROSS						4
#DEFINE cnCHART_SYMBOL_TYPE_PLUS						5
#DEFINE cnCHART_SYMBOL_TYPE_STAR						6
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE_DOWN				7

***************************************************************************************************************************
*-- LinearGradient Mode
***************************************************************************************************************************
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_HORIZONTAL			0
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_VERTICAL			1
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL	2
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_BACKWARDDIAGONAL	3

***************************************************************************************************************************
*-- Enumeration type that defines how a curve is drawn
***************************************************************************************************************************
#DEFINE cnCHART_LINE_STEP_TYPE_FORWARD					0
#DEFINE cnCHART_LINE_STEP_TYPE_REARWARD					1
#DEFINE cnCHART_LINE_STEP_TYPE_NONE						2

***************************************************************************************************************************
*-- Enumeration that specifies a Z-Order position for ChartItem objects
***************************************************************************************************************************
#DEFINE cnCHART_ZORDER_TYPE_BehindAll								0
#DEFINE cnCHART_ZORDER_TYPE_BehindAxisFill							1
#DEFINE cnCHART_ZORDER_TYPE_BehindAxis								2
#DEFINE cnCHART_ZORDER_TYPE_BehindCurves 							3
#DEFINE cnCHART_ZORDER_TYPE_BehindAxisBorder						4
#DEFINE cnCHART_ZORDER_TYPE_BehindLegend							5
#DEFINE cnCHART_ZORDER_TYPE_InFront									6


LOCAL loFile
LOCAL loChartCurve
LOCAL loBoxItem
LOCAL loTextItem

LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath

CD LEFT(SYS(16,0), RAT('\', SYS(16,0)))

lcOutPutFileName = 'ComboChart'
lcOutPutFilePath = JUSTPATH(SYS(16,0)) + '\OutPut\'

SET PATH TO  ..\..\..\
SET CLASSLIB TO Chart IN FRX2Any.APP ALIAS Chart


loFile = CREATEOBJ('Chart.ChartFile')


IF TYPE('loFile') = 'O'

	WITH loFile
*-- Unlock FRX2Any
		.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = 'ReportOutput'
		.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = 'c:\MyApp\MyOutPut\'
		.cSaveFolder     = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
		.nOutPutType     = cnOUTPUT_SCREEN

*-- Default value is cnIMAGE_OUTPUT_FILE_FORMAT_GIF
		.nImageFileType  = cnIMAGE_OUTPUT_FILE_FORMAT_PNG

*-- Specify Chart's properties
*-- For description of all Chart's properties and methods, please see FRX2Any help file.

		WITH .oPanel
*-- Set the main Title of the Chart
			.cTitle 	  = 'Line chart with Band'

			.nWidth  = 800
			.nHeight = 550

			WITH .oFontSpec
				.cFamily   = 'Arial Black'
			ENDWITH


			WITH .oAxisFill
*-- Create a linear gradient color-fill
				.SetGradientFill( RGB(255,255,255),RGB(255, 255, 190), cnGDIPLUS_LINEARGRADIENTMODE_VERTICAL)
			ENDWITH

			WITH .oXAxis
*-- Set Title for X axis
				.cTitle = 'Sequence'

				.lShowGrid		= .T.
				.lShowMinorGrid = .T.
			ENDWITH

			WITH .oYAxis
*-- Set Title for Y axis
				.cTitle = 'Temperature, C'

				.lShowGrid		= .T.
				.lShowMinorGrid = .T.
			ENDWITH

*-- Add a Curve Item with Circle symbols, and 'Larry' in the legend

*-- Make up some random data points
			DIMENSION laX[7] AS INTEGER

			laX[1]  = 100
			laX[2]  = 200
			laX[3]  = 300
			laX[4]  = 400
			laX[5]  = 500
			laX[6]  = 600
			laX[7]  = 700

			DIMENSION laY1[7]

			laY1[1]  = 100
			laY1[2]  = 115
			laY1[3]  = 75
			laY1[4]  = 22
			laY1[5]  = 95
			laY1[6]  = 45
			laY1[7]  = 10

			DIMENSION laY2[7]

			laY2[1]  = 90
			laY2[2]  = 100
			laY2[3]  = 95
			laY2[4]  = 35
			laY2[5]  = 80
			laY2[6]  = 35
			laY2[7]  = 35

			DIMENSION laY3[7]

			laY3[1]  = 80
			laY3[2]  = 110
			laY3[3]  = 65
			laY3[4]  = 15
			laY3[5]  = 54
			laY3[6]  = 67
			laY3[7]  = 18

			loChartCurve = .AddCurve('Curve 1', @laX, @laY1, RGB(255, 0, 0), cnCHART_SYMBOL_TYPE_SQUARE)

			IF !ISNULL(loChartCurve)

				WITH loChartCurve

					WITH .oSymbol
						WITH .oFill
*-- Create a solid color-fill
							.SetSolidFill(RGB(255, 255, 255))
						ENDWITH
					ENDWITH
				ENDWITH

			ENDIF


			loChartCurve = .AddCurve('Curve 2', @laX, @laY2, RGB(0, 128, 0), cnCHART_SYMBOL_TYPE_SQUARE)

			IF !ISNULL(loChartCurve)

				WITH loChartCurve

					WITH .oSymbol
						WITH .oFill
*-- Create a solid color-fill
							.SetSolidFill(RGB(255, 255, 255))
						ENDWITH
					ENDWITH
				ENDWITH

			ENDIF


			loChartCurve = .AddCurve('Curve 3', @laX, @laY3, RGB(0, 0, 255), cnCHART_SYMBOL_TYPE_SQUARE)

			IF !ISNULL(loChartCurve)

				WITH loChartCurve

					WITH .oSymbol
						WITH .oFill
*-- Create a solid color-fill
							.SetSolidFill(RGB(255, 255, 255))
						ENDWITH
					ENDWITH
				ENDWITH

			ENDIF

*-- Draw a box item to highlight a value range
			loBoxItem = .AddBoxItem(0, 100, 800, 30)

			loBoxItem.oFill.SetGradientFill(RGB(255,255,255),RGB(179,255,179),  cnGDIPLUS_LINEARGRADIENTMODE_VERTICAL)
*-- Use the BehindAxis zorder to draw the highlight beneath the grid lines
			loBoxItem.nZOrder = cnCHART_ZORDER_TYPE_BehindAxis

*-- Add a text item to label the highlighted range
			loTextItem = .AddTextItem('Optimal'  + CHR(10) +  'Range', 700, 85 ) 

			WITH loTextItem.oFontSpec

				.oFill.lVisible   = .F.
				.oBorder.lVisible = .F.

				.nSize			  = 10	

			ENDWITH

		ENDWITH

		.SAVE()

		.RELEASE()

	ENDWITH

ENDIF

